@@ -1,6 +1,7 @@
 import datetime
 import typing
 import os
+import tempfile
 
 from dataclasses import dataclass
 
@@ -29,17 +30,17 @@ class IngestionSessionContext:
         return IngestionSessionContext(
             ingestion_session_id=int(os.getenv("INGESTION_SESSION_ID", 0)),
             entities_output_location=os.getenv(
-                "ENTITIES_OUTPUT_LOCATION", "file://./output/entities/"
+                "ENTITIES_OUTPUT_LOCATION", f'file://{tempfile.mkdtemp()}/'
             ),
             assets_output_location=os.getenv(
-                "ASSETS_OUTPUT_LOCATION", "file://./output/assets/"
+                "ASSETS_OUTPUT_LOCATION", f'file://{tempfile.mkdtemp()}/'
             ),
             errors_output_location=os.getenv(
-                "ERRORS_OUTPUT_LOCATION", "file://./output/errors/"
+                "ERRORS_OUTPUT_LOCATION", f'file://{tempfile.mkdtemp()}/'
             ),
             relationships_output_location=os.getenv(
                 "RELATIONSHIPS_OUTPUT_LOCATION",
-                "file://./output/relationships/",
+                f'file://{tempfile.mkdtemp()}/'
             ),
         )
 
